@@ -1,16 +1,18 @@
-package Devel::AssertOS::MacOSX::v10_9;
+package Devel::AssertOS::MacOSX::v10_10;
 
 use Devel::CheckOS;
 use strict;
+use warnings;
+no warnings 'redefine';
 
 our $VERSION = '1.0';
 
 sub os_is {
     Devel::CheckOS::os_is('MacOSX') &&
-    `sw_vers -productVersion` =~ /^10\.9\./ ? 1 : 0;
+    `sw_vers -productVersion` =~ /^10\.10\./ ? 1 : 0;
 }
 
-sub expn { "The operating system is some version of OS X Mavericks (10.9)" }
+sub expn { "The operating system is some version of OS X Yosemite (10.10)" }
 
 Devel::CheckOS::die_unsupported() unless(os_is());
 
